@@ -2,7 +2,8 @@
 import os
 import shutil
 from pkg_resources import resource_filename
-from logya import Logya
+from __init__ import Logya
+
 
 class Create(Logya):
     """Create a basic template for generating a Web site with Logya."""
@@ -12,4 +13,4 @@ class Create(Logya):
         super(self.__class__, self).__init__()
         src = resource_filename(__name__, 'sites/docs')
         dst = os.path.join(self.dir_current, name)
-        shutil.copytree(src, dst)
\ No newline at end of file
+        shutil.copytree(src, dst)
