@@ -1,7 +1,9 @@
 # -*- coding: utf-8 -*-
 import os
+import urllib
 from jinja2 import Environment, BaseLoader, TemplateNotFound
 
+
 class Template():
     """Class to handle templates."""
 
@@ -9,8 +11,11 @@ class Template():
         """Initialize template environment."""
 
         self.vars = {}
+        self.doc_vars = {}
         self.dir_templates = dir_templates
         self.env = Environment(loader=TemplateLoader(self.dir_templates))
+        # add urlencode filter to template
+        self.env.filters['urlencode'] = lambda x: urllib.quote_plus(x)
 
     def get_env(self):
         """Return template environment."""
@@ -22,17 +27,36 @@ class Template():
 
         self.vars[name] = value
 
+    def add_doc_var(self, name, value):
+        """Add to template variables."""
+
+        self.doc_vars[name] = value
+
+    def empty_doc_vars(self):
+        """Empty doc_vars dictionary."""
+
+        self.doc_vars = {}
+
     def get_var(self, name):
         """Return value of template variables with given name."""
 
         return self.vars[name]
 
     def get_vars(self):
-        """Return all template variables."""
+        """Return non doc-specific template variables."""
 
         return self.vars
 
+    def get_all_vars(self):
+        """Return alltemplate variables combines."""
+
+        all_vars = self.vars.copy()
+        all_vars.update(self.doc_vars)
+        return all_vars
+
+
 class TemplateLoader(BaseLoader):
+
     """Class to handle template Loading."""
 
     def __init__(self, path):
